@@ -29,6 +29,7 @@ from os.path import join, exists, abspath
 
 import numpy
 
+from tomo.convert import getOrderFromList
 from pyworkflow.tests import BaseTest, setupTestProject
 from pyworkflow.utils import magentaStr, createLink
 from pyworkflow.object import Pointer
@@ -37,11 +38,11 @@ from pwem.protocols import ProtSplitSet, ProtSetFilter, ProtSetEditor
 from tomo.protocols.protocol_ts_import import MDoc
 from . import DataSet
 from ..constants import BOTTOM_LEFT_CORNER, TOP_LEFT_CORNER, ERR_COORDS_FROM_SQLITE_NO_MATCH, ERR_NO_TOMOMASKS_GEN, \
-    ERR_NON_MATCHING_TOMOS
+    ERR_NON_MATCHING_TOMOS, SCIPION
 import tomo.protocols
 from ..protocols import ProtImportTomograms, ProtImportTomomasks
 from ..protocols.protocol_import_coordinates import IMPORT_FROM_AUTO, ProtImportCoordinates3D
-from ..protocols.protocol_import_coordinates_from_scipion import ProtImportCoordinates3DFromScipion
+from ..protocols.protocol_import_coordinates_from_scipion import ProtImportCoordinates3DFromScipion, outputObjs
 from ..utils import existsPlugin
 
 from imod.protocols import ProtImodTomoNormalization
@@ -163,10 +164,10 @@ class TestTomoImportSetOfCoordinates3D(BaseTest):
                                               samplingRate=samplingRate)
 
         self.launchProtocol(protImportTomogram)
-        outputTomos = getattr(protImportTomogram, 'outputTomograms', None)
-        self.assertIsNotNone(outputTomos, 'No tomograms were genetated.')
 
-        return outputTomos
+        self.assertSetSize(protImportTomogram.Tomograms, size=1, msg='No tomograms were generated.')
+
+        return protImportTomogram.Tomograms
 
     def _runTomoImportSetOfCoordinates(self, pattern, program, ext):
         sRate = 5.5
@@ -190,7 +191,7 @@ class TestTomoImportSetOfCoordinates3D(BaseTest):
                                                       boxSize=boxSize)
 
         self.launchProtocol(protImportCoordsFromSqlite)
-        return getattr(protImportCoordsFromSqlite, 'outputCoordinates', None), \
+        return getattr(protImportCoordsFromSqlite, outputObjs.coordinates.name, None), \
                getattr(protImportCoordsFromSqlite, 'outputTomograms', None)
 
     def testImport3dCoordsFromSqlite_FullMatch(self):
@@ -272,6 +273,27 @@ class TestTomoImportSetOfCoordinates3D(BaseTest):
         output = getattr(protCoordinates, 'outputCoordinates', None)
         self.assertCoordinates(output, 5, boxSize, samplingRate)
 
+        # From txt
+        protCoordinates = self._runTomoImportSetOfCoordinates('*.cbox', 'CRYOLO', 'CBOX')
+        output = getattr(protCoordinates, 'outputCoordinates', None)
+        self.assertCoordinates(output, 3, boxSize, samplingRate)
+
+        def checkCoordinates(expectedValues, coordSet):
+
+            for index, row in enumerate(expectedValues):
+                coord = coordSet[index + 1]
+                self.assertEqual(coord.getX(SCIPION), row[0], "X coordinate not converted properly")
+                self.assertEqual(coord.getY(SCIPION), row[1], "Y coordinate not converted properly")
+                self.assertEqual(coord.getZ(SCIPION), row[2], "Z coordinate not converted properly")
+
+        expectedCoords = [
+            [-512, -512, -256],
+            [0, 0, 0],
+            [512, 512, 256],
+        ]
+
+        checkCoordinates(expectedCoords, output)
+
         # From emantomo file
         if existsPlugin('emantomo'):
             protCoordinates = self._runTomoImportSetOfCoordinates('*.json', 'EMAN', 'JSON')
@@ -301,8 +323,8 @@ class TestTomoImportSetOfCoordinates3D(BaseTest):
         self.assertIsNotNone(coordSet.getPrecedents(), "Tomograms not associated in the output set")
 
         for coord in coordSet.iterCoordinates():
-            # Access the coordinate, this should work if tomograms are assocciated
-            Y = coord.getY(BOTTOM_LEFT_CORNER)
+            # Access the coordinate, this should work if tomograms are associated
+            X = coord.getY(BOTTOM_LEFT_CORNER)
             Y = coord.getY(TOP_LEFT_CORNER)
 
             break
@@ -317,7 +339,7 @@ class TestTomoImportTomograms(BaseTest):
         cls.dataset = DataSet.getDataSet('tomo-em')
         cls.tomogram = cls.dataset.getFile('*.em')
 
-    def _runImportTomograms(self):
+    def _runImportTomograms(self)-> tomo.protocols.ProtImportTomograms:
         protImport = self.newProtocol(
             tomo.protocols.ProtImportTomograms,
             filesPath=self.tomogram,
@@ -328,7 +350,7 @@ class TestTomoImportTomograms(BaseTest):
         self.launchProtocol(protImport)
         return protImport
 
-    def _runImportTomograms2(self):
+    def _runImportTomograms2(self)->tomo.protocols.ProtImportTomograms:
         protImport = self.newProtocol(
             tomo.protocols.ProtImportTomograms,
             filesPath=self.tomogram,
@@ -339,11 +361,9 @@ class TestTomoImportTomograms(BaseTest):
 
     def test_importTomograms(self):
         protImport = self._runImportTomograms()
-        output = getattr(protImport, 'outputTomograms', None)
-        self.assertIsNotNone(output,
-                             "There was a problem with Import Tomograms protocol")
+        self.assertSetSize(protImport.Tomograms, size=2, msg="There was a problem with Import Tomograms protocol")
 
-        for tomogram in protImport.outputTomograms.iterItems():
+        for tomogram in protImport.Tomograms.iterItems():
             self.assertTrue(tomogram.getXDim() == 1024,
                             "There was a problem with Import Tomograms protocol")
             self.assertIsNotNone(tomogram.getYDim() == 1024,
@@ -357,11 +377,10 @@ class TestTomoImportTomograms(BaseTest):
             break
 
         protImport2 = self._runImportTomograms2()
-        output2 = getattr(protImport2, 'outputTomograms', None)
-        self.assertIsNotNone(output2,
+        self.assertSetSize(protImport.Tomograms, size=2, msg=
                              "There was a problem with Import Tomograms protocol")
 
-        for tomogram in protImport2.outputTomograms.iterItems():
+        for tomogram in protImport2.Tomograms.iterItems():
             self.assertTrue(tomogram.getXDim() == 1024,
                             "There was a problem with Import Tomograms protocol")
             self.assertIsNotNone(tomogram.getYDim() == 1024,
@@ -402,7 +421,7 @@ class TestTomoBaseProtocols(BaseTest):
 
     def test_importTiltSeriesM(self):
         protImport = self._runImportTiltSeriesM()
-        self.assertSetSize(protImport.outputTiltSeriesM, 2)
+        self.assertSetSize(protImport.outputTiltSeriesM, size=2, msg="Importing tilt series movies is failing")
 
         return protImport
 
@@ -814,10 +833,9 @@ class TestImportTomoMasks(BaseTest):
                                              samplingRate=cls.samplingRate)
 
         cls.launchProtocol(protImportTomogram)
-        outputTomos = getattr(protImportTomogram, 'outputTomograms', None)
-        cls.assertIsNotNone(outputTomos, 'No tomograms were genetated.')
+        cls.assertIsNotNone(protImportTomogram.Tomograms, 'No tomograms were generated importing %s.' % filesPath)
 
-        return outputTomos
+        return protImportTomogram.Tomograms
 
     @classmethod
     def _normalizeTomo(cls):
@@ -828,7 +846,7 @@ class TestImportTomoMasks(BaseTest):
 
         cls.launchProtocol(protTomoNormalization)
         outputTomos = getattr(protTomoNormalization, 'Tomograms', None)
-        cls.assertIsNotNone(outputTomos, 'No tomograms were genetated in tomo normalization.')
+        cls.assertIsNotNone(outputTomos, 'No tomograms were generated in tomo normalization.')
 
         return outputTomos
 
@@ -841,8 +859,7 @@ class TestImportTomoMasks(BaseTest):
         self.launchProtocol(protImportTomomasks)
         tomoMaskSet = getattr(protImportTomomasks, 'outputTomoMasks', None)
 
-        self.assertIsNotNone(tomoMaskSet, 'No tomograms were genetated.')
-        self.assertSetSize(tomoMaskSet, 1)
+        self.assertSetSize(tomoMaskSet, size=1, msg="Importing tomoMasks failed.")
         self.assertEqual(tomoMaskSet.getDimensions(), (464, 464, 250))
         self.assertEqual(tomoMaskSet.getSamplingRate(), 2 * self.samplingRate)
         self.assertFalse(protImportTomomasks.warnMsg)
@@ -868,3 +885,23 @@ class TestImportTomoMasks(BaseTest):
         with self.assertRaises(Exception) as eType:
             self.launchProtocol(protImportTomomasks)
             self.assertEqual(str(eType.exception), ERR_NON_MATCHING_TOMOS)
+
+class TestConvert(BaseTest):
+
+    def test_list_order(self):
+
+        myList = [20,40,50,10,30]
+        orders = getOrderFromList(myList)
+        self.assertEqual(orders, [2,4,5,1,3])
+
+        myList = [20, 40, 50, 10, 30]
+        orders = getOrderFromList(myList)
+        self.assertEqual(orders, [2, 4, 5, 1, 3])
+
+        # Simulate dose list in symmetric dose scheme
+        myList = [24,21,12,9,3,6,15,18,27]
+        orders = getOrderFromList(myList)
+        self.assertEqual(orders, [8,7,4,3,1,2,5,6,9])
+
+
+
